@@ -3,15 +3,13 @@ package Astro::App::Satpass2::ParseTime::Date::Manip::v6;
 use strict;
 use warnings;
 
-use Astro::Coord::ECI::Utils 0.059 qw{ looks_like_number };
-use Astro::App::Satpass2::Utils qw{ time_gm };
-use Time::Local;
+use Astro::Coord::ECI::Utils 0.077 qw{ looks_like_number time_gm };
 
 use base qw{ Astro::App::Satpass2::ParseTime::Date::Manip };
 
 use Astro::App::Satpass2::Utils qw{ load_package };
 
-our $VERSION = '0.031_03';
+our $VERSION = '0.031_04';
 
 my $invalid;
 
